@@ -445,13 +445,10 @@ AMP_element_sequence="$AMP_element_sequence sos"
 AMP_element_sequence="$AMP_element_sequence cloud-init-datasources"
 AMP_element_sequence="$AMP_element_sequence remove-default-ints"
 
-# SELinux systems
-if [ "${AMP_BASEOS}" = "centos-minimal" ] || [ "${AMP_BASEOS}" = "fedora" ] || [ "${AMP_BASEOS}" = "rhel" ]; then
-    if [ "$AMP_ENABLE_FULL_MAC_SECURITY" -ne 1 ]; then
+if [ "$AMP_ENABLE_FULL_MAC_SECURITY" -ne 1 ]; then
+    # SELinux systems
+    if [ "${AMP_BASEOS}" = "centos-minimal" ] || [ "${AMP_BASEOS}" = "fedora" ] || [ "${AMP_BASEOS}" = "rhel" ]; then
         AMP_element_sequence="$AMP_element_sequence selinux-permissive"
-    else
-        # If SELinux is enforced, the amphora image requires the amphora-selinux policies
-        AMP_element_sequence="$AMP_element_sequence amphora-selinux"
     fi
 fi
 
@@ -521,4 +518,4 @@ if [ -z "$DIB_REPOREF_amphora_agent" ]; then
 else
     echo "Successfully built the amphora using the $DIB_REPOREF_amphora_agent amphora-agent."
 fi
-echo "Amphora image size: `stat -c "%n %s" $AMP_OUTPUTFILENAME`"
+echo "Amphora image size: `stat -c "%n %s" $AMP_OUTPUTFILENAME.$AMP_IMAGETYPE`"
