@@ -12,31 +12,30 @@
 # License for the specific language governing permissions and limitations
 #    under the License.
 
-import ipaddress
 import os
 import re
 import socket
 import subprocess
 
 import pyroute2
-import six
 import webob
 
-import netifaces
 from octavia.amphorae.backends.agent import api_server
 from octavia.amphorae.backends.agent.api_server import util
+from octavia.amphorae.backends.utils import network_utils
 from octavia.common import constants as consts
+from octavia.common import exceptions
 
 
 class AmphoraInfo(object):
     def __init__(self, osutils):
         self._osutils = osutils
 
-    def compile_amphora_info(self, extend_udp_driver=None):
+    def compile_amphora_info(self, extend_lvs_driver=None):
         extend_body = {}
-        if extend_udp_driver:
-            extend_body = self._get_extend_body_from_udp_driver(
-                extend_udp_driver)
+        if extend_lvs_driver:
+            extend_body = self._get_extend_body_from_lvs_driver(
+                extend_lvs_driver)
         body = {'hostname': socket.gethostname(),
                 'haproxy_version':
                     self._get_version_of_installed_package('haproxy'),
@@ -45,17 +44,18 @@ class AmphoraInfo(object):
             body.update(extend_body)
         return webob.Response(json=body)
 
-    def compile_amphora_details(self, extend_udp_driver=None):
+    def compile_amphora_details(self, extend_lvs_driver=None):
         haproxy_listener_list = sorted(util.get_listeners())
         extend_body = {}
-        udp_listener_list = []
-        if extend_udp_driver:
-            udp_listener_list = util.get_udp_listeners()
-            extend_data = self._get_extend_body_from_udp_driver(
-                extend_udp_driver)
-            udp_count = self._count_udp_listener_processes(extend_udp_driver,
-                                                           udp_listener_list)
-            extend_body['udp_listener_process_count'] = udp_count
+        lvs_listener_list = []
+        if extend_lvs_driver:
+            lvs_listener_list = util.get_lvs_listeners()
+            extend_data = self._get_extend_body_from_lvs_driver(
+                extend_lvs_driver)
+            lvs_count = self._count_lvs_listener_processes(
+                extend_lvs_driver,
+                lvs_listener_list)
+            extend_body['lvs_listener_process_count'] = lvs_count
             extend_body.update(extend_data)
         meminfo = self._get_meminfo()
         cpu = self._cpu()
@@ -88,8 +88,8 @@ class AmphoraInfo(object):
                 'topology': consts.TOPOLOGY_SINGLE,
                 'topology_status': consts.TOPOLOGY_STATUS_OK,
                 'listeners': sorted(list(
-                    set(haproxy_listener_list + udp_listener_list)))
-                if udp_listener_list else haproxy_listener_list,
+                    set(haproxy_listener_list + lvs_listener_list)))
+                if lvs_listener_list else haproxy_listener_list,
                 'packages': {}}
         if extend_body:
             body.update(extend_body)
@@ -109,16 +109,16 @@ class AmphoraInfo(object):
                 num += 1
         return num
 
-    def _count_udp_listener_processes(self, udp_driver, listener_list):
+    def _count_lvs_listener_processes(self, lvs_driver, listener_list):
         num = 0
         for listener_id in listener_list:
-            if udp_driver.is_listener_running(listener_id):
+            if lvs_driver.is_listener_running(listener_id):
                 # optional check if it's still running
                 num += 1
         return num
 
-    def _get_extend_body_from_udp_driver(self, extend_udp_driver):
-        extend_info = extend_udp_driver.get_subscribed_amp_compile_info()
+    def _get_extend_body_from_lvs_driver(self, extend_lvs_driver):
+        extend_info = extend_lvs_driver.get_subscribed_amp_compile_info()
         extend_data = {}
         for extend in extend_info:
             package_version = self._get_version_of_installed_package(extend)
@@ -127,8 +127,8 @@ class AmphoraInfo(object):
 
     def _get_meminfo(self):
         re_parser = re.compile(r'^(?P<key>\S*):\s*(?P<value>\d*)\s*kB')
-        result = dict()
-        with open('/proc/meminfo', 'r') as meminfo:
+        result = {}
+        with open('/proc/meminfo', 'r', encoding='utf-8') as meminfo:
             for line in meminfo:
                 match = re_parser.match(line)
                 if not match:
@@ -138,7 +138,7 @@ class AmphoraInfo(object):
         return result
 
     def _cpu(self):
-        with open('/proc/stat') as f:
+        with open('/proc/stat', encoding='utf-8') as f:
             cpu = f.readline()
             vals = cpu.split(' ')
             return {
@@ -153,13 +153,13 @@ class AmphoraInfo(object):
             }
 
     def _load(self):
-        with open('/proc/loadavg') as f:
+        with open('/proc/loadavg', encoding='utf-8') as f:
             load = f.readline()
             vals = load.split(' ')
             return vals[:3]
 
     def _get_networks(self):
-        networks = dict()
+        networks = {}
         with pyroute2.NetNS(consts.AMPHORA_NAMESPACE) as netns:
             for interface in netns.get_links():
                 interface_name = None
@@ -176,65 +176,15 @@ class AmphoraInfo(object):
         return networks
 
     def get_interface(self, ip_addr):
-
         try:
-            ip_version = ipaddress.ip_address(six.text_type(ip_addr)).version
-        except Exception:
+            interface = network_utils.get_interface_name(
+                ip_addr, net_ns=consts.AMPHORA_NAMESPACE)
+        except exceptions.InvalidIPAddress:
+            return webob.Response(json=dict(message="Invalid IP address"),
+                                  status=400)
+        except exceptions.NotFound:
             return webob.Response(
-                json=dict(message="Invalid IP address"), status=400)
-
-        if ip_version == 4:
-            address_format = netifaces.AF_INET
-        elif ip_version == 6:
-            address_format = netifaces.AF_INET6
-        else:
-            return webob.Response(
-                json=dict(message="Bad IP address version"), status=400)
-
-        # We need to normalize the address as IPv6 has multiple representations
-        # fe80:0000:0000:0000:f816:3eff:fef2:2058 == fe80::f816:3eff:fef2:2058
-        normalized_addr = socket.inet_ntop(address_format,
-                                           socket.inet_pton(address_format,
-                                                            ip_addr))
-
-        with pyroute2.NetNS(consts.AMPHORA_NAMESPACE) as netns:
-            for addr in netns.get_addr():
-                # Save the interface index as IPv6 records don't list a
-                # textual interface
-                interface_idx = addr['index']
-                # Save the address family (IPv4/IPv6) for use normalizing
-                # the IP address for comparison
-                interface_af = addr['family']
-                # Search through the attributes of each address record
-                for attr in addr['attrs']:
-                    # Look for the attribute name/value pair for the address
-                    if attr[0] == 'IFA_ADDRESS':
-                        # Compare the normalized address with the address we
-                        # we are looking for.  Since we have matched the name
-                        # above, attr[1] is the address value
-                        if normalized_addr == socket.inet_ntop(
-                                interface_af,
-                                socket.inet_pton(interface_af, attr[1])):
-
-                            # Lookup the matching interface name by
-                            # getting the interface with the index we found
-                            # in the above address search
-                            lookup_int = netns.get_links(interface_idx)
-                            # Search through the attributes of the matching
-                            # interface record
-                            for int_attr in lookup_int[0]['attrs']:
-                                # Look for the attribute name/value pair
-                                # that includes the interface name
-                                if int_attr[0] == 'IFLA_IFNAME':
-                                    # Return the response with the matching
-                                    # interface name that is in int_attr[1]
-                                    # for the matching interface attribute
-                                    # name
-                                    return webob.Response(
-                                        json=dict(message='OK',
-                                                  interface=int_attr[1]),
-                                        status=200)
-
-        return webob.Response(
-            json=dict(message="Error interface not found for IP address"),
-            status=404)
+                json=dict(message="Error interface not found for IP address"),
+                status=404)
+        return webob.Response(json=dict(message='OK', interface=interface),
+                              status=200)
