@@ -66,7 +66,7 @@ class BaseOS(object):
     def write_vip_interface_file(self, interface, vip, ip_version,
                                  prefixlen, gateway,
                                  mtu, vrrp_ip,
-                                 host_routes, fixed_ips=None):
+                                 host_routes):
         vip_interface = interface_file.VIPInterfaceFile(
             name=interface,
             mtu=mtu,
@@ -76,7 +76,6 @@ class BaseOS(object):
             gateway=gateway,
             vrrp_ip=vrrp_ip,
             host_routes=host_routes,
-            fixed_ips=fixed_ips,
             topology=CONF.controller_worker.loadbalancer_topology)
         vip_interface.write()
 
@@ -88,23 +87,38 @@ class BaseOS(object):
         port_interface.write()
 
     @classmethod
-    def bring_interface_up(cls, interface, name):
+    def _bring_if_up(cls, interface, what):
         cmd = ("ip netns exec {ns} amphora-interface up {params}".format(
             ns=consts.AMPHORA_NAMESPACE, params=interface))
         LOG.debug("Executing: %s", cmd)
         try:
             out = subprocess.check_output(cmd.split(),
                                           stderr=subprocess.STDOUT)
-            for line in out.decode('utf-8').split('\n'):
-                LOG.debug(line)
+            LOG.debug(out)
         except subprocess.CalledProcessError as e:
             LOG.error('Failed to set up %s due to error: %s %s', interface,
                       e, e.output)
             raise exceptions.HTTPException(
                 response=webob.Response(json=dict(
-                    message='Error plugging {0}'.format(name),
+                    message='Error plugging {0}'.format(what),
                     details=e.output), status=500))
 
+    @classmethod
+    def _bring_if_down(cls, interface):
+        cmd = ("ip netns exec {ns} amphora-interface down {params}".format(
+            ns=consts.AMPHORA_NAMESPACE, params=interface))
+        LOG.debug("Executing: %s", cmd)
+        try:
+            subprocess.check_output(cmd.split(), stderr=subprocess.STDOUT)
+        except subprocess.CalledProcessError as e:
+            LOG.info('Ignoring failure to set %s down due to error: %s %s',
+                     interface, e, e.output)
+
+    @classmethod
+    def bring_interfaces_up(cls, ip, primary_interface):
+        cls._bring_if_down(primary_interface)
+        cls._bring_if_up(primary_interface, 'VIP')
+
 
 class Ubuntu(BaseOS):
 
