@@ -15,14 +15,10 @@
 import csv
 import socket
 
-from oslo_log import log as logging
-
 from octavia.common import constants as consts
 from octavia.common import utils as octavia_utils
 from octavia.i18n import _
 
-LOG = logging.getLogger(__name__)
-
 
 class HAProxyQuery(object):
     """Class used for querying the HAProxy statistics socket.
@@ -33,9 +29,9 @@ class HAProxyQuery(object):
     """
 
     def __init__(self, stats_socket):
-        """Initialize the class
+        """stats_socket
 
-        :param stats_socket: Path to the HAProxy statistics socket file.
+            Path to the HAProxy statistics socket file.
         """
 
         self.socket = stats_socket
@@ -101,7 +97,11 @@ class HAProxyQuery(object):
                 server_id=server_id))
         list_results = results[2:].split('\n')
         csv_reader = csv.DictReader(list_results)
-        return list(csv_reader)
+        stats_list = list(csv_reader)
+        # We don't want to report the internal prometheus proxy stats
+        # up to the control plane as it shouldn't be billed traffic
+        return [stat for stat in stats_list
+                if "prometheus" not in stat['pxname']]
 
     def get_pool_status(self):
         """Get status for each server and the pool as a whole.
@@ -119,6 +119,11 @@ class HAProxyQuery(object):
         for line in results:
             # pxname: pool, svname: server_name, status: status
 
+            # We don't want to report the internal prometheus proxy stats
+            # up to health manager as it shouldn't be billed traffic
+            if 'prometheus' in line['pxname']:
+                continue
+
             if line['pxname'] not in final_results:
                 final_results[line['pxname']] = dict(members={})
 
@@ -138,23 +143,3 @@ class HAProxyQuery(object):
                 final_results[line['pxname']]['members'][line['svname']] = (
                     line['status'])
         return final_results
-
-    def save_state(self, state_file_path):
-        """Save haproxy connection state to a file.
-
-        :param state_file_path: Absolute path to the state file
-
-        :returns: bool (True if success, False otherwise)
-        """
-
-        try:
-            result = self._query('show servers state')
-            # No need for binary mode, the _query converts bytes to ascii.
-            with open(state_file_path, 'w', encoding='utf-8') as fh:
-                fh.write(result)
-            return True
-        except Exception as e:
-            # Catch any exception - may be socket issue, or write permission
-            # issue as well.
-            LOG.warning("Unable to save state: %r", e)
-            return False
