@@ -39,7 +39,6 @@ from octavia.common.tls_utils import cert_parser
 from octavia.common import utils
 from octavia.db import api as db_apis
 from octavia.db import repositories as repo
-from octavia.network import data_models as network_models
 
 
 LOG = logging.getLogger(__name__)
@@ -79,17 +78,15 @@ class HaproxyAmphoraLoadBalancerDriver(
             connection_logging=CONF.haproxy_amphora.connection_logging)
         self.lvs_jinja = jinja_udp_cfg.LvsJinjaTemplater()
 
-    def _get_haproxy_versions(self, amphora, timeout_dict=None):
+    def _get_haproxy_versions(self, amphora):
         """Get major and minor version number from haproxy
 
         Example: ['1', '6']
 
         :returns version_list: A list with the major and minor numbers
         """
-        self._populate_amphora_api_version(
-            amphora, timeout_dict=timeout_dict)
-        amp_info = self.clients[amphora.api_version].get_info(
-            amphora, timeout_dict=timeout_dict)
+        self._populate_amphora_api_version(amphora)
+        amp_info = self.clients[amphora.api_version].get_info(amphora)
         haproxy_version_string = amp_info['haproxy_version']
 
         return haproxy_version_string.split('.')[:2]
@@ -139,8 +136,7 @@ class HaproxyAmphoraLoadBalancerDriver(
             return
 
         # Check which HAProxy version is on the amp
-        haproxy_versions = self._get_haproxy_versions(
-            amphora, timeout_dict=timeout_dict)
+        haproxy_versions = self._get_haproxy_versions(amphora)
         # Check which config style to use
         api_version = self._populate_amphora_api_version(amphora)
         if api_version[0] == 0 and api_version[1] <= 5:  # 0.5 or earlier
@@ -263,18 +259,15 @@ class HaproxyAmphoraLoadBalancerDriver(
         self._populate_amphora_api_version(amp)
         self.clients[amp.api_version].update_cert_for_rotation(amp, pem)
 
-    def _apply(self, func_name, loadbalancer, amphora=None, *args, **kwargs):
+    def _apply(self, func_name, loadbalancer, amphora=None, *args):
         if amphora is None:
             amphorae = loadbalancer.amphorae
         else:
             amphorae = [amphora]
 
-        timeout_dict = args[0]
-
         for amp in amphorae:
             if amp.status != consts.DELETED:
-                api_version = self._populate_amphora_api_version(
-                    amp, timeout_dict=timeout_dict)
+                api_version = self._populate_amphora_api_version(amp)
                 # Check which config style to use
                 if api_version[0] == 0 and api_version[1] <= 5:
                     # 0.5 or earlier
@@ -376,14 +369,11 @@ class HaproxyAmphoraLoadBalancerDriver(
             self.clients[amphora.api_version].delete_listener(
                 amphora, listener.load_balancer.id)
 
-    def get_info(self, amphora, raise_retry_exception=False,
-                 timeout_dict=None):
+    def get_info(self, amphora, raise_retry_exception=False):
         self._populate_amphora_api_version(
-            amphora, raise_retry_exception=raise_retry_exception,
-            timeout_dict=timeout_dict)
+            amphora, raise_retry_exception=raise_retry_exception)
         return self.clients[amphora.api_version].get_info(
-            amphora, raise_retry_exception=raise_retry_exception,
-            timeout_dict=timeout_dict)
+            amphora, raise_retry_exception=raise_retry_exception)
 
     def get_diagnostics(self, amphora):
         pass
@@ -391,33 +381,23 @@ class HaproxyAmphoraLoadBalancerDriver(
     def finalize_amphora(self, amphora):
         pass
 
-    def _build_net_info(self, port, amphora, subnet, mtu=None):
-        # NOTE(blogan): using the vrrp port here because that
-        # is what the allowed address pairs network driver sets
-        # this particular port to.  This does expose a bit of
-        # tight coupling between the network driver and amphora
-        # driver.  We will need to revisit this to try and remove
-        # this tight coupling.
-        # NOTE (johnsom): I am loading the vrrp_ip into the
-        # net_info structure here so that I don't break
-        # compatibility with old amphora agent versions.
-        host_routes = [{'nexthop': hr[consts.NEXTHOP],
-                        'destination': hr[consts.DESTINATION]}
-                       for hr in subnet[consts.HOST_ROUTES]]
-        net_info = {'subnet_cidr': subnet[consts.CIDR],
-                    'gateway': subnet[consts.GATEWAY_IP],
-                    'mac_address': port[consts.MAC_ADDRESS],
-                    'vrrp_ip': amphora[consts.VRRP_IP],
-                    'mtu': mtu or port[consts.NETWORK][consts.MTU],
-                    'host_routes': host_routes}
-        return net_info
-
     def post_vip_plug(self, amphora, load_balancer, amphorae_network_config,
                       vrrp_port=None, vip_subnet=None):
         if amphora.status != consts.DELETED:
             self._populate_amphora_api_version(amphora)
             if vip_subnet is None:
-                vip_subnet = amphorae_network_config.get(amphora.id).vip_subnet
+                subnet = amphorae_network_config.get(amphora.id).vip_subnet
+            else:
+                subnet = vip_subnet
+            # NOTE(blogan): using the vrrp port here because that
+            # is what the allowed address pairs network driver sets
+            # this particular port to.  This does expose a bit of
+            # tight coupling between the network driver and amphora
+            # driver.  We will need to revisit this to try and remove
+            # this tight coupling.
+            # NOTE (johnsom): I am loading the vrrp_ip into the
+            # net_info structure here so that I don't break
+            # compatibility with old amphora agent versions.
             if vrrp_port is None:
                 port = amphorae_network_config.get(amphora.id).vrrp_port
                 mtu = port.network.mtu
@@ -426,9 +406,15 @@ class HaproxyAmphoraLoadBalancerDriver(
                 mtu = port.network['mtu']
             LOG.debug("Post-VIP-Plugging with vrrp_ip %s vrrp_port %s",
                       amphora.vrrp_ip, port.id)
-            net_info = self._build_net_info(
-                port.to_dict(recurse=True), amphora.to_dict(),
-                vip_subnet.to_dict(recurse=True), mtu)
+            host_routes = [{'nexthop': hr.nexthop,
+                            'destination': hr.destination}
+                           for hr in subnet.host_routes]
+            net_info = {'subnet_cidr': subnet.cidr,
+                        'gateway': subnet.gateway_ip,
+                        'mac_address': port.mac_address,
+                        'vrrp_ip': amphora.vrrp_ip,
+                        'mtu': mtu,
+                        'host_routes': host_routes}
             try:
                 self.clients[amphora.api_version].plug_vip(
                     amphora, load_balancer.vip.ip_address, net_info)
@@ -437,7 +423,7 @@ class HaproxyAmphoraLoadBalancerDriver(
                             'skipping post_vip_plug',
                             {'mac': port.mac_address})
 
-    def post_network_plug(self, amphora, port, amphora_network_config):
+    def post_network_plug(self, amphora, port):
         fixed_ips = []
         for fixed_ip in port.fixed_ips:
             host_routes = [{'nexthop': hr.nexthop,
@@ -445,25 +431,11 @@ class HaproxyAmphoraLoadBalancerDriver(
                            for hr in fixed_ip.subnet.host_routes]
             ip = {'ip_address': fixed_ip.ip_address,
                   'subnet_cidr': fixed_ip.subnet.cidr,
-                  'host_routes': host_routes,
-                  'gateway': fixed_ip.subnet.gateway_ip}
+                  'host_routes': host_routes}
             fixed_ips.append(ip)
         port_info = {'mac_address': port.mac_address,
                      'fixed_ips': fixed_ips,
                      'mtu': port.network.mtu}
-        if port.id == amphora.vrrp_port_id:
-            if isinstance(amphora_network_config,
-                          network_models.AmphoraNetworkConfig):
-                amphora_network_config = amphora_network_config.to_dict(
-                    recurse=True)
-            # We have to special-case sharing the vrrp port and pass through
-            # enough extra information to populate the whole VIP port
-            net_info = self._build_net_info(
-                port.to_dict(recurse=True), amphora.to_dict(),
-                amphora_network_config[consts.VIP_SUBNET],
-                port.network.mtu)
-            net_info['vip'] = amphora.ha_ip
-            port_info['vip_net_info'] = net_info
         try:
             self._populate_amphora_api_version(amphora)
             self.clients[amphora.api_version].plug_network(amphora, port_info)
@@ -839,10 +811,8 @@ class AmphoraAPIClient0_5(AmphoraAPIClientBase):
             amp, 'listeners/{listener_id}'.format(listener_id=listener_id))
         return exc.check_exception(r, (404,))
 
-    def get_info(self, amp, raise_retry_exception=False,
-                 timeout_dict=None):
-        r = self.get(amp, "info", raise_retry_exception=raise_retry_exception,
-                     timeout_dict=timeout_dict)
+    def get_info(self, amp, raise_retry_exception=False):
+        r = self.get(amp, "info", raise_retry_exception=raise_retry_exception)
         if exc.check_exception(r):
             return r.json()
         return None
@@ -970,10 +940,8 @@ class AmphoraAPIClient1_0(AmphoraAPIClientBase):
             amp, 'listeners/{object_id}'.format(object_id=object_id))
         return exc.check_exception(r, (404,))
 
-    def get_info(self, amp, raise_retry_exception=False,
-                 timeout_dict=None):
-        r = self.get(amp, "info", raise_retry_exception=raise_retry_exception,
-                     timeout_dict=timeout_dict)
+    def get_info(self, amp, raise_retry_exception=False):
+        r = self.get(amp, "info", raise_retry_exception=raise_retry_exception)
         if exc.check_exception(r):
             return r.json()
         return None
