@@ -98,7 +98,7 @@ class UDPStatusGetter(object):
         except Exception as e:
             LOG.warning('Health Manager experienced an exception processing a '
                         'heartbeat message from %s. Ignoring this packet. '
-                        'Exception: %s', srcaddr, e)
+                        'Exception: %s', srcaddr, str(e))
             raise exceptions.InvalidHMACException()
         obj['recv_time'] = time.time()
         return obj, srcaddr[0]
@@ -115,7 +115,7 @@ class UDPStatusGetter(object):
         except Exception as e:
             LOG.warning('Health Manager experienced an exception processing a '
                         'heartbeat packet. Ignoring this packet. '
-                        'Exception: %s', e)
+                        'Exception: %s', str(e))
         else:
             self.health_executor.submit(self.health_updater.update_health,
                                         obj, srcaddr)
@@ -241,7 +241,7 @@ class UpdateHealthDb:
         except Exception as e:
             LOG.exception('Health update for amphora %(amp)s encountered '
                           'error %(err)s. Skipping health update.',
-                          {'amp': health['id'], 'err': e})
+                          {'amp': health['id'], 'err': str(e)})
         # TODO(johnsom) We need to set a warning threshold here
         LOG.debug('Health Update finished in: %s seconds',
                   timeit.default_timer() - start_time)
@@ -357,35 +357,33 @@ class UpdateHealthDb:
                             self._update_listener_count_for_UDP(
                                 session, db_lb, expected_listener_count))
         else:
-            # If this is not a spare amp, log and skip it.
             amp = self.amphora_repo.get(session, id=health['id'])
-            if not amp or amp.load_balancer_id:
-                # This is debug and not warning because this can happen under
-                # normal deleting operations.
-                LOG.debug('Received a health heartbeat from amphora %s with '
-                          'IP %s that should not exist. This amphora may be '
-                          'in the process of being deleted, in which case you '
-                          'will only see this message a few '
-                          'times', health['id'], srcaddr)
-                if not amp:
-                    LOG.warning('The amphora %s with IP %s is missing from '
-                                'the DB, so it cannot be automatically '
-                                'deleted (the compute_id is unknown). An '
-                                'operator must manually delete it from the '
-                                'compute service.', health['id'], srcaddr)
-                    return
-                # delete the amp right there
-                try:
-                    compute = stevedore_driver.DriverManager(
-                        namespace='octavia.compute.drivers',
-                        name=CONF.controller_worker.compute_driver,
-                        invoke_on_load=True
-                    ).driver
-                    compute.delete(amp.compute_id)
-                    return
-                except Exception as e:
-                    LOG.info("Error deleting amp %s with IP %s Error: %s",
-                             health['id'], srcaddr, e)
+            # This is debug and not warning because this can happen under
+            # normal deleting operations.
+            LOG.debug('Received a health heartbeat from amphora %s with '
+                      'IP %s that should not exist. This amphora may be '
+                      'in the process of being deleted, in which case you '
+                      'will only see this message a few '
+                      'times', health['id'], srcaddr)
+            if not amp:
+                LOG.warning('The amphora %s with IP %s is missing from '
+                            'the DB, so it cannot be automatically '
+                            'deleted (the compute_id is unknown). An '
+                            'operator must manually delete it from the '
+                            'compute service.', health['id'], srcaddr)
+                return
+            # delete the amp right there
+            try:
+                compute = stevedore_driver.DriverManager(
+                    namespace='octavia.compute.drivers',
+                    name=CONF.controller_worker.compute_driver,
+                    invoke_on_load=True
+                ).driver
+                compute.delete(amp.compute_id)
+                return
+            except Exception as e:
+                LOG.info("Error deleting amp %s with IP %s Error: %s",
+                         health['id'], srcaddr, str(e))
             expected_listener_count = 0
 
         listeners = health['listeners']
@@ -426,7 +424,7 @@ class UpdateHealthDb:
                         {'id': health['id'], 'found': len(listeners),
                          'expected': expected_listener_count})
 
-        # Don't try to update status for spares pool amphora
+        # Don't try to update status for bogus or old spares pool amphora
         if not db_lb:
             return
 
@@ -520,17 +518,16 @@ class UpdateHealthDb:
                     session, db_pool_id, db_pool_dict, pools,
                     lb_status, processed_pools, potential_offline_pools)
 
-        for pool_id in potential_offline_pools:
+        for pool_id, pool in potential_offline_pools.items():
             # Skip if we eventually found a status for this pool
             if pool_id in processed_pools:
                 continue
             try:
                 # If the database doesn't already show the pool offline, update
-                if potential_offline_pools[pool_id] != constants.OFFLINE:
+                if pool != constants.OFFLINE:
                     self._update_status(
                         session, self.pool_repo, constants.POOL,
-                        pool_id, constants.OFFLINE,
-                        potential_offline_pools[pool_id])
+                        pool_id, constants.OFFLINE, pool)
             except sqlalchemy.orm.exc.NoResultFound:
                 LOG.error("Pool %s is not in DB", pool_id)
 
