@@ -15,10 +15,9 @@
 
 import errno
 import os
+import socketserver
 import threading
 
-import six.moves.socketserver as socketserver
-
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
@@ -169,3 +168,4 @@ def get_listener(exit_event):
     LOG.info('Driver get listener shutdown finished.')
     server.server_close()
     _cleanup_socket_file(CONF.driver_agent.get_socket_path)
+    LOG.info("UDS server was closed and socket was cleaned up.")
