@@ -23,7 +23,7 @@ LOG = logging.getLogger(__name__)
 
 class NoopManager(object):
     def __init__(self):
-        super(NoopManager, self).__init__()
+        super().__init__()
         self.driverconfig = {}
 
     # Load Balancer
@@ -148,10 +148,11 @@ class NoopManager(object):
         self.driverconfig[new_member.member_id] = (
             new_member, 'member_update')
 
-    def member_batch_update(self, members):
+    def member_batch_update(self, pool_id, members):
         for member in members:
-            LOG.debug('Provider %s no-op, member_batch_update member %s',
-                      self.__class__.__name__, member.member_id)
+            LOG.debug('Provider %s no-op, member_batch_update pool_id %s '
+                      'member %s',
+                      self.__class__.__name__, pool_id, member.member_id)
 
             self.driverconfig[member.member_id] = (member,
                                                    'member_batch_update')
@@ -241,10 +242,27 @@ class NoopManager(object):
         flavor_hash = hash(frozenset(flavor_metadata))
         self.driverconfig[flavor_hash] = (flavor_metadata, 'validate_flavor')
 
+    # Availability Zone
+    def get_supported_availability_zone_metadata(self):
+        LOG.debug(
+            'Provider %s no-op, get_supported_availability_zone_metadata',
+            self.__class__.__name__)
+
+        return {"compute_zone": "The compute availability zone to use for "
+                "this loadbalancer."}
+
+    def validate_availability_zone(self, availability_zone_metadata):
+        LOG.debug('Provider %s no-op, validate_availability_zone metadata: %s',
+                  self.__class__.__name__, availability_zone_metadata)
+
+        availability_zone_hash = hash(frozenset(availability_zone_metadata))
+        self.driverconfig[availability_zone_hash] = (
+            availability_zone_metadata, 'validate_availability_zone')
+
 
 class NoopProviderDriver(driver_base.ProviderDriver):
     def __init__(self):
-        super(NoopProviderDriver, self).__init__()
+        super().__init__()
         self.driver = NoopManager()
 
     # Load Balancer
@@ -294,8 +312,8 @@ class NoopProviderDriver(driver_base.ProviderDriver):
     def member_update(self, old_member, new_member):
         self.driver.member_update(old_member, new_member)
 
-    def member_batch_update(self, members):
-        self.driver.member_batch_update(members)
+    def member_batch_update(self, pool_id, members):
+        self.driver.member_batch_update(pool_id, members)
 
     # Health Monitor
     def health_monitor_create(self, healthmonitor):
@@ -333,3 +351,10 @@ class NoopProviderDriver(driver_base.ProviderDriver):
 
     def validate_flavor(self, flavor_metadata):
         self.driver.validate_flavor(flavor_metadata)
+
+    # Availability Zone
+    def get_supported_availability_zone_metadata(self):
+        return self.driver.get_supported_availability_zone_metadata()
+
+    def validate_availability_zone(self, availability_zone_metadata):
+        self.driver.validate_availability_zone(availability_zone_metadata)
