@@ -12,6 +12,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from octavia_lib.api.drivers import data_models as driver_dm
+from octavia_lib.common import constants as lib_consts
 from oslo_config import cfg
 from oslo_db import exception as odb_exceptions
 from oslo_log import log as logging
@@ -21,7 +23,6 @@ from pecan import request as pecan_request
 from wsme import types as wtypes
 from wsmeext import pecan as wsme_pecan
 
-from octavia.api.drivers import data_models as driver_dm
 from octavia.api.drivers import driver_factory
 from octavia.api.drivers import utils as driver_utils
 from octavia.api.v2.controllers import base
@@ -43,7 +44,7 @@ class L7PolicyController(base.BaseController):
     RBAC_TYPE = constants.RBAC_L7POLICY
 
     def __init__(self):
-        super(L7PolicyController, self).__init__()
+        super().__init__()
 
     @wsme_pecan.wsexpose(l7policy_types.L7PolicyRootResponse, wtypes.text,
                          [wtypes.text], ignore_extra_args=True)
@@ -103,13 +104,13 @@ class L7PolicyController(base.BaseController):
 
             return self.repositories.l7policy.create(lock_session,
                                                      **l7policy_dict)
-        except odb_exceptions.DBDuplicateEntry:
-            raise exceptions.IDAlreadyExists()
-        except odb_exceptions.DBError:
+        except odb_exceptions.DBDuplicateEntry as e:
+            raise exceptions.IDAlreadyExists() from e
+        except odb_exceptions.DBError as e:
             # TODO(blogan): will have to do separate validation protocol
             # before creation or update since the exception messages
             # do not give any information as to what constraint failed
-            raise exceptions.InvalidOption(value='', option='')
+            raise exceptions.InvalidOption(value='', option='') from e
 
     @wsme_pecan.wsexpose(l7policy_types.L7PolicyRootResponse,
                          body=l7policy_types.L7PolicyRootPOST, status_code=201)
@@ -129,6 +130,11 @@ class L7PolicyController(base.BaseController):
         self._auth_validate_action(context, l7policy.project_id,
                                    constants.RBAC_POST)
 
+        # PROMETHEUS listeners cannot have l7policies attached
+        if listener.protocol == lib_consts.PROTOCOL_PROMETHEUS:
+            raise exceptions.ListenerNoChildren(
+                protocol=lib_consts.PROTOCOL_PROMETHEUS)
+
         # Make sure any pool specified by redirect_pool_id exists
         if l7policy.redirect_pool_id:
             db_pool = self._get_db_pool(
