@@ -37,7 +37,7 @@ from octavia.common import data_models
 from octavia.common import exceptions
 from octavia.common import stats
 from octavia.common import utils
-import octavia.common.validate as validate
+from octavia.common import validate
 from octavia.db import api as db_api
 from octavia.db import prepare as db_prepare
 from octavia.i18n import _
