@@ -229,6 +229,9 @@ class PoolsController(base.BaseController):
                                    constants.RBAC_POST)
 
         if pool.listener_id and listener:
+            if listener.protocol == lib_consts.PROTOCOL_PROMETHEUS:
+                raise exceptions.ListenerNoChildren(
+                    protocol=lib_consts.PROTOCOL_PROMETHEUS)
             self._validate_protocol(listener.protocol, pool.protocol)
 
         if pool.protocol in (constants.PROTOCOL_UDP,
@@ -457,7 +460,7 @@ class PoolsController(base.BaseController):
 
         with db_api.get_lock_session() as lock_session:
             self._test_lb_and_listener_statuses(
-                lock_session, lb_id=db_pool.load_balancer_id,
+                context.session, lb_id=db_pool.load_balancer_id,
                 listener_ids=self._get_affected_listener_ids(db_pool))
 
             # Prepare the data for the driver data model
