@@ -12,6 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from octavia_lib.common import constants as lib_constants
 from wsme import types as wtypes
 
 from octavia.api.common import types
@@ -83,6 +84,9 @@ class PoolResponse(BasePoolType):
     ca_tls_container_ref = wtypes.wsattr(wtypes.StringType())
     crl_container_ref = wtypes.wsattr(wtypes.StringType())
     tls_enabled = wtypes.wsattr(bool)
+    tls_ciphers = wtypes.wsattr(wtypes.StringType())
+    tls_versions = wtypes.wsattr(wtypes.ArrayType(wtypes.StringType()))
+    alpn_protocols = wtypes.wsattr(wtypes.ArrayType(types.AlpnProtocolType()))
 
     @classmethod
     def from_data_model(cls, data_model, children=False):
@@ -114,6 +118,9 @@ class PoolResponse(BasePoolType):
         pool.members = [
             member_model.from_data_model(i) for i in data_model.members]
 
+        pool.tls_versions = data_model.tls_versions
+        pool.alpn_protocols = data_model.alpn_protocols
+
         return pool
 
 
@@ -142,8 +149,9 @@ class PoolPOST(BasePoolType):
     admin_state_up = wtypes.wsattr(bool, default=True)
     listener_id = wtypes.wsattr(wtypes.UuidType())
     loadbalancer_id = wtypes.wsattr(wtypes.UuidType())
-    protocol = wtypes.wsattr(wtypes.Enum(str, *constants.SUPPORTED_PROTOCOLS),
-                             mandatory=True)
+    protocol = wtypes.wsattr(
+        wtypes.Enum(str, *lib_constants.POOL_SUPPORTED_PROTOCOLS),
+        mandatory=True)
     lb_algorithm = wtypes.wsattr(
         wtypes.Enum(str, *constants.SUPPORTED_LB_ALGORITHMS),
         mandatory=True)
@@ -158,6 +166,10 @@ class PoolPOST(BasePoolType):
     ca_tls_container_ref = wtypes.wsattr(wtypes.StringType(max_length=255))
     crl_container_ref = wtypes.wsattr(wtypes.StringType(max_length=255))
     tls_enabled = wtypes.wsattr(bool, default=False)
+    tls_ciphers = wtypes.wsattr(wtypes.StringType(max_length=2048))
+    tls_versions = wtypes.wsattr(wtypes.ArrayType(wtypes.StringType(
+        max_length=32)))
+    alpn_protocols = wtypes.wsattr(wtypes.ArrayType(types.AlpnProtocolType()))
 
 
 class PoolRootPOST(types.BaseType):
@@ -177,6 +189,10 @@ class PoolPUT(BasePoolType):
     ca_tls_container_ref = wtypes.wsattr(wtypes.StringType(max_length=255))
     crl_container_ref = wtypes.wsattr(wtypes.StringType(max_length=255))
     tls_enabled = wtypes.wsattr(bool)
+    tls_ciphers = wtypes.wsattr(wtypes.StringType(max_length=2048))
+    tls_versions = wtypes.wsattr(wtypes.ArrayType(wtypes.StringType(
+        max_length=32)))
+    alpn_protocols = wtypes.wsattr(wtypes.ArrayType(types.AlpnProtocolType()))
 
 
 class PoolRootPut(types.BaseType):
@@ -188,7 +204,8 @@ class PoolSingleCreate(BasePoolType):
     name = wtypes.wsattr(wtypes.StringType(max_length=255))
     description = wtypes.wsattr(wtypes.StringType(max_length=255))
     admin_state_up = wtypes.wsattr(bool, default=True)
-    protocol = wtypes.wsattr(wtypes.Enum(str, *constants.SUPPORTED_PROTOCOLS))
+    protocol = wtypes.wsattr(
+        wtypes.Enum(str, *lib_constants.POOL_SUPPORTED_PROTOCOLS))
     lb_algorithm = wtypes.wsattr(
         wtypes.Enum(str, *constants.SUPPORTED_LB_ALGORITHMS))
     session_persistence = wtypes.wsattr(SessionPersistencePOST)
@@ -199,6 +216,10 @@ class PoolSingleCreate(BasePoolType):
     ca_tls_container_ref = wtypes.wsattr(wtypes.StringType(max_length=255))
     crl_container_ref = wtypes.wsattr(wtypes.StringType(max_length=255))
     tls_enabled = wtypes.wsattr(bool, default=False)
+    tls_ciphers = wtypes.wsattr(wtypes.StringType(max_length=2048))
+    tls_versions = wtypes.wsattr(wtypes.ArrayType(wtypes.StringType(
+        max_length=32)))
+    alpn_protocols = wtypes.wsattr(wtypes.ArrayType(types.AlpnProtocolType()))
 
 
 class PoolStatusResponse(BasePoolType):
