@@ -84,6 +84,8 @@ api_opts = [
                 help=_("Allow users to create TLS Terminated listeners?")),
     cfg.BoolOpt('allow_ping_health_monitors', default=True,
                 help=_("Allow users to create PING type Health Monitors?")),
+    cfg.BoolOpt('allow_prometheus_listeners', default=True,
+                help=_("Allow users to create PROMETHEUS type listeners?")),
     cfg.DictOpt('enabled_provider_drivers',
                 help=_('A comma separated list of dictionaries of the '
                        'enabled provider driver names and descriptions. '
@@ -354,8 +356,9 @@ haproxy_amphora_opts = [
     cfg.IntOpt('active_connection_max_retries',
                default=15,
                help=_('Retry threshold for connecting to active amphorae.')),
-    cfg.IntOpt('active_connection_rety_interval',
+    cfg.IntOpt('active_connection_retry_interval',
                default=2,
+               deprecated_name='active_connection_rety_interval',
                help=_('Retry timeout between connection attempts in '
                       'seconds for active amphora.')),
     cfg.IntOpt('failover_connection_max_retries',
@@ -621,20 +624,6 @@ certificate_opts = [
 ]
 
 house_keeping_opts = [
-    cfg.IntOpt('spare_check_interval',
-               deprecated_for_removal=True,
-               deprecated_since='Victoria',
-               deprecated_reason='Spares Pool support will be removed in the '
-                                 'X release.',
-               default=30,
-               help=_('Spare check interval in seconds')),
-    cfg.IntOpt('spare_amphora_pool_size',
-               deprecated_for_removal=True,
-               deprecated_since='Victoria',
-               deprecated_reason='Spares Pool support will be removed in the '
-                                 'X release.',
-               default=0,
-               help=_('Number of spare amphorae')),
     cfg.IntOpt('cleanup_interval',
                default=30,
                help=_('DB cleanup interval in seconds')),
