@@ -13,7 +13,6 @@
 #    under the License.
 
 from oslo_config import cfg
-from oslo_log import log
 
 from octavia.common import config
 from octavia.common import rpc
@@ -23,6 +22,5 @@ def prepare_service(argv=None):
     """Sets global config from config file and sets up logging."""
     argv = argv or []
     config.init(argv[1:])
-    log.set_defaults()
     config.setup_logging(cfg.CONF)
     rpc.init()
