@@ -25,28 +25,26 @@ LOG = logging.getLogger(__name__)
 
 class NoopManager(object):
     def __init__(self):
-        super(NoopManager, self).__init__()
+        super().__init__()
         self.computeconfig = {}
 
     def build(self, name="amphora_name", amphora_flavor=None,
-              image_id=None, image_tag=None, image_owner=None,
-              key_name=None, sec_groups=None, network_ids=None,
-              config_drive_files=None, user_data=None, port_ids=None,
-              server_group_id=None, availability_zone=None):
+              image_tag=None, image_owner=None, key_name=None, sec_groups=None,
+              network_ids=None, config_drive_files=None, user_data=None,
+              port_ids=None, server_group_id=None, availability_zone=None):
         LOG.debug("Compute %s no-op, build name %s, amphora_flavor %s, "
-                  "image_id %s, image_tag %s, image_owner %s, key_name %s, "
-                  "sec_groups %s, network_ids %s, config_drive_files %s, "
-                  "user_data %s, port_ids %s, server_group_id %s, "
-                  "availability_zone %s",
+                  "image_tag %s, image_owner %s, key_name %s, sec_groups %s, "
+                  "network_ids %s, config_drive_files %s, user_data %s, "
+                  "port_ids %s, server_group_id %s, availability_zone %s",
                   self.__class__.__name__,
-                  name, amphora_flavor, image_id, image_tag, image_owner,
+                  name, amphora_flavor, image_tag, image_owner,
                   key_name, sec_groups, network_ids, config_drive_files,
                   user_data, port_ids, server_group_id, availability_zone)
-        self.computeconfig[(name, amphora_flavor, image_id, image_tag,
+        self.computeconfig[(name, amphora_flavor, image_tag,
                             image_owner, key_name, user_data,
                             server_group_id)] = (
             name, amphora_flavor,
-            image_id, image_tag, image_owner, key_name, sec_groups,
+            image_tag, image_owner, key_name, sec_groups,
             network_ids, config_drive_files, user_data, port_ids,
             server_group_id, 'build')
         compute_id = uuidutils.generate_uuid()
@@ -122,17 +120,16 @@ class NoopManager(object):
 
 class NoopComputeDriver(driver_base.ComputeBase):
     def __init__(self):
-        super(NoopComputeDriver, self).__init__()
+        super().__init__()
         self.driver = NoopManager()
 
     def build(self, name="amphora_name", amphora_flavor=None,
-              image_id=None, image_tag=None, image_owner=None,
-              key_name=None, sec_groups=None, network_ids=None,
-              config_drive_files=None, user_data=None, port_ids=None,
-              server_group_id=None, availability_zone=None):
+              image_tag=None, image_owner=None, key_name=None, sec_groups=None,
+              network_ids=None, config_drive_files=None, user_data=None,
+              port_ids=None, server_group_id=None, availability_zone=None):
 
         compute_id = self.driver.build(name, amphora_flavor,
-                                       image_id, image_tag, image_owner,
+                                       image_tag, image_owner,
                                        key_name, sec_groups, network_ids,
                                        config_drive_files, user_data, port_ids,
                                        server_group_id, availability_zone)
