@@ -202,12 +202,12 @@ class LoadBalancerFlows(object):
         )
         flows.append(
             network_tasks.HandleNetworkDeltas(
-                requires=constants.DELTAS, provides=constants.UPDATED_PORTS
+                requires=constants.DELTAS, provides=constants.ADDED_PORTS
             )
         )
         flows.append(
             amphora_driver_tasks.AmphoraePostNetworkPlug(
-                requires=(constants.LOADBALANCER, constants.UPDATED_PORTS)
+                requires=(constants.LOADBALANCER, constants.ADDED_PORTS)
             )
         )
         flows.append(
@@ -391,7 +391,7 @@ class LoadBalancerFlows(object):
             constants.CONN_MAX_RETRIES:
                 CONF.haproxy_amphora.active_connection_max_retries,
             constants.CONN_RETRY_INTERVAL:
-                CONF.haproxy_amphora.active_connection_rety_interval}
+                CONF.haproxy_amphora.active_connection_retry_interval}
 
         if failed_amp:
             if failed_amp.role in (constants.ROLE_MASTER,
