@@ -56,6 +56,9 @@ class AmpListenersUpdate(BaseAmphoraTask):
         # in a failover flow with both amps failing. Skip it and let
         # health manager fix it.
         try:
+            # Make sure we have a fresh load balancer object
+            loadbalancer = self.loadbalancer_repo.get(db_apis.get_session(),
+                                                      id=loadbalancer.id)
             self.amphora_driver.update_amphora_listeners(
                 loadbalancer, amphora, timeout_dict)
         except Exception as e:
@@ -75,6 +78,9 @@ class AmphoraIndexListenerUpdate(BaseAmphoraTask):
         # in a failover flow with both amps failing. Skip it and let
         # health manager fix it.
         try:
+            # Make sure we have a fresh load balancer object
+            loadbalancer = self.loadbalancer_repo.get(db_apis.get_session(),
+                                                      id=loadbalancer.id)
             self.amphora_driver.update_amphora_listeners(
                 loadbalancer, amphorae[amphora_index], timeout_dict)
         except Exception as e:
@@ -248,7 +254,6 @@ class AmphoraPostVIPPlug(BaseAmphoraTask):
             return
         LOG.warning("Reverting post vip plug.")
         self.task_utils.mark_amphora_status_error(amphora.id)
-        self.task_utils.mark_loadbalancer_prov_status_error(loadbalancer.id)
 
 
 class AmphoraePostVIPPlug(BaseAmphoraTask):
@@ -262,13 +267,6 @@ class AmphoraePostVIPPlug(BaseAmphoraTask):
                                       loadbalancer,
                                       amphorae_network_config)
 
-    def revert(self, result, loadbalancer, *args, **kwargs):
-        """Handle a failed amphora vip plug notification."""
-        if isinstance(result, failure.Failure):
-            return
-        LOG.warning("Reverting amphorae post vip plug.")
-        self.task_utils.mark_loadbalancer_prov_status_error(loadbalancer.id)
-
 
 class AmphoraCertUpload(BaseAmphoraTask):
     """Upload a certificate to the amphora."""
@@ -448,6 +446,6 @@ class AmphoraConfigUpdate(BaseAmphoraTask):
             self.amphora_driver.update_amphora_agent_config(amphora,
                                                             agent_config)
         except driver_except.AmpDriverNotImplementedError:
-            LOG.error('Amphora {} does not support agent configuration '
+            LOG.error('Amphora %s does not support agent configuration '
                       'update. Please update the amphora image for this '
-                      'amphora. Skipping.'.format(amphora.id))
+                      'amphora. Skipping.', amphora.id)
