@@ -53,101 +53,42 @@ class CalculateAmphoraDelta(BaseNetworkTask):
 
     default_provides = constants.DELTA
 
-    def execute(self, loadbalancer, amphora, availability_zone):
+    def execute(self, loadbalancer, amphora, availability_zone,
+                vrrp_port=None):
         LOG.debug("Calculating network delta for amphora id: %s", amphora.id)
 
-        vip_subnet_to_net_map = {
-            loadbalancer.vip.subnet_id:
-            loadbalancer.vip.network_id,
-        }
-
-        # Figure out what networks we want
-        # seed with lb network(s)
+        if vrrp_port is None:
+            vrrp_port = self.network_driver.get_port(amphora.vrrp_port_id)
         if (availability_zone and
                 availability_zone.get(constants.MANAGEMENT_NETWORK)):
-            management_nets = [
-                availability_zone.get(constants.MANAGEMENT_NETWORK)]
+            management_nets = [availability_zone.get(
+                constants.MANAGEMENT_NETWORK)]
         else:
             management_nets = CONF.controller_worker.amp_boot_network_list
-
-        desired_subnet_to_net_map = {}
-        for mgmt_net_id in management_nets:
-            for subnet_id in self.network_driver.get_network(
-                    mgmt_net_id).subnets:
-                desired_subnet_to_net_map[subnet_id] = mgmt_net_id
-        desired_subnet_to_net_map.update(vip_subnet_to_net_map)
+        desired_network_ids = {vrrp_port.network_id}.union(management_nets)
 
         for pool in loadbalancer.pools:
-            for member in pool.members:
-                if (member.subnet_id and
-                        member.provisioning_status !=
-                        constants.PENDING_DELETE):
-                    member_network = self.network_driver.get_subnet(
-                        member.subnet_id).network_id
-                    desired_subnet_to_net_map[member.subnet_id] = (
-                        member_network)
+            member_networks = [
+                self.network_driver.get_subnet(member.subnet_id).network_id
+                for member in pool.members
+                if member.subnet_id
+            ]
+            desired_network_ids.update(member_networks)
 
-        desired_network_ids = set(desired_subnet_to_net_map.values())
-        desired_subnet_ids = set(desired_subnet_to_net_map)
+        nics = self.network_driver.get_plugged_networks(amphora.compute_id)
+        # assume we don't have two nics in the same network
+        actual_network_nics = dict((nic.network_id, nic) for nic in nics)
 
-        # Calculate Network deltas
-        nics = self.network_driver.get_plugged_networks(
-            amphora.compute_id)
-        # we don't have two nics in the same network
-        network_to_nic_map = {nic.network_id: nic for nic in nics}
-
-        plugged_network_ids = set(network_to_nic_map)
-
-        del_ids = plugged_network_ids - desired_network_ids
-        delete_nics = [n_data_models.Interface(
-            network_id=net_id,
-            port_id=network_to_nic_map[net_id].port_id)
-            for net_id in del_ids]
-
-        add_ids = desired_network_ids - plugged_network_ids
-        add_nics = [n_data_models.Interface(
-            network_id=add_net_id,
-            fixed_ips=[
-                n_data_models.FixedIP(
-                    subnet_id=subnet_id)
-                for subnet_id, net_id in desired_subnet_to_net_map.items()
-                if net_id == add_net_id])
-            for add_net_id in add_ids]
-
-        # Calculate member Subnet deltas
-        plugged_subnets = {}
-        for nic in network_to_nic_map.values():
-            for fixed_ip in nic.fixed_ips or []:
-                plugged_subnets[fixed_ip.subnet_id] = nic.network_id
-
-        plugged_subnet_ids = set(plugged_subnets)
-        del_subnet_ids = plugged_subnet_ids - desired_subnet_ids
-        add_subnet_ids = desired_subnet_ids - plugged_subnet_ids
-
-        def _subnet_updates(subnet_ids, subnets):
-            updates = []
-            for s in subnet_ids:
-                network_id = subnets[s]
-                nic = network_to_nic_map.get(network_id)
-                port_id = nic.port_id if nic else None
-                updates.append({
-                    constants.SUBNET_ID: s,
-                    constants.NETWORK_ID: network_id,
-                    constants.PORT_ID: port_id
-                })
-            return updates
-
-        add_subnets = _subnet_updates(add_subnet_ids,
-                                      desired_subnet_to_net_map)
-        del_subnets = _subnet_updates(del_subnet_ids,
-                                      plugged_subnets)
+        del_ids = set(actual_network_nics) - desired_network_ids
+        delete_nics = list(
+            actual_network_nics[net_id] for net_id in del_ids)
 
+        add_ids = desired_network_ids - set(actual_network_nics)
+        add_nics = list(n_data_models.Interface(
+            network_id=net_id) for net_id in add_ids)
         delta = n_data_models.Delta(
-            amphora_id=amphora.id,
-            compute_id=amphora.compute_id,
-            add_nics=add_nics, delete_nics=delete_nics,
-            add_subnets=add_subnets,
-            delete_subnets=del_subnets)
+            amphora_id=amphora.id, compute_id=amphora.compute_id,
+            add_nics=add_nics, delete_nics=delete_nics)
         return delta
 
 
@@ -293,87 +234,28 @@ class HandleNetworkDelta(BaseNetworkTask):
     Plug or unplug networks based on delta
     """
 
-    def _fill_port_info(self, port):
-        port.network = self.network_driver.get_network(port.network_id)
-        for fixed_ip in port.fixed_ips:
-            fixed_ip.subnet = self.network_driver.get_subnet(
-                fixed_ip.subnet_id)
-
     def execute(self, amphora, delta):
         """Handle network plugging based off deltas."""
-        updated_ports = {}
+        added_ports = {}
+        added_ports[amphora.id] = []
         for nic in delta.add_nics:
-            subnet_id = nic.fixed_ips[0].subnet_id
-            interface = self.network_driver.plug_network(
-                amphora.compute_id, nic.network_id)
+            interface = self.network_driver.plug_network(delta.compute_id,
+                                                         nic.network_id)
             port = self.network_driver.get_port(interface.port_id)
-            # nova may plugged undesired subnets (it plugs one of the subnets
-            # of the network), we can safely unplug the subnets we don't need,
-            # the desired subnet will be added in the 'ADD_SUBNETS' loop.
-            extra_subnets = [
-                fixed_ip.subnet_id
-                for fixed_ip in port.fixed_ips
-                if fixed_ip.subnet_id != subnet_id]
-            for subnet_id in extra_subnets:
-                port = self.network_driver.unplug_fixed_ip(
-                    port_id=interface.port_id, subnet_id=subnet_id)
-            self._fill_port_info(port)
-            updated_ports[port.network_id] = port
-
-        for update in delta.add_subnets:
-            network_id = update[constants.NETWORK_ID]
-            # Get already existing port from Deltas or
-            # newly created port from updated_ports dict
-            port_id = (update[constants.PORT_ID] or
-                       updated_ports[network_id].id)
-            subnet_id = update[constants.SUBNET_ID]
-            # Avoid duplicated subnets
-            has_subnet = False
-            if network_id in updated_ports:
-                has_subnet = any(
-                    fixed_ip.subnet_id == subnet_id
-                    for fixed_ip in updated_ports[network_id].fixed_ips)
-            if not has_subnet:
-                port = self.network_driver.plug_fixed_ip(
-                    port_id=port_id, subnet_id=subnet_id)
-                self._fill_port_info(port)
-                updated_ports[network_id] = port
-
-        for update in delta.delete_subnets:
-            network_id = update[constants.NETWORK_ID]
-            port_id = update[constants.PORT_ID]
-            subnet_id = update[constants.SUBNET_ID]
-            port = self.network_driver.unplug_fixed_ip(
-                port_id=port_id, subnet_id=subnet_id)
-            self._fill_port_info(port)
-            # In neutron, when removing an ipv6 subnet (with slaac) from a
-            # port, it just ignores it.
-            # https://bugs.launchpad.net/neutron/+bug/1945156
-            # When it happens, don't add the port to the updated_ports dict
-            has_subnet = any(
-                fixed_ip.subnet_id == subnet_id
-                for fixed_ip in port.fixed_ips)
-            if not has_subnet:
-                updated_ports[network_id] = port
-
+            port.network = self.network_driver.get_network(port.network_id)
+            for fixed_ip in port.fixed_ips:
+                fixed_ip.subnet = self.network_driver.get_subnet(
+                    fixed_ip.subnet_id)
+            added_ports[amphora.id].append(port)
         for nic in delta.delete_nics:
-            network_id = nic.network_id
             try:
-                self.network_driver.unplug_network(
-                    amphora.compute_id, network_id)
+                self.network_driver.unplug_network(delta.compute_id,
+                                                   nic.network_id)
             except base.NetworkNotFound:
-                LOG.debug("Network %s not found", network_id)
+                LOG.debug("Network %d not found ", nic.network_id)
             except Exception:
                 LOG.exception("Unable to unplug network")
-
-            port_id = nic.port_id
-            try:
-                self.network_driver.delete_port(port_id)
-            except Exception:
-                LOG.exception("Unable to delete the port")
-
-            updated_ports.pop(network_id, None)
-        return {amphora.id: list(updated_ports.values())}
+        return added_ports
 
     def revert(self, result, amphora, delta, *args, **kwargs):
         """Handle a network plug or unplug failures."""
@@ -392,14 +274,7 @@ class HandleNetworkDelta(BaseNetworkTask):
                 self.network_driver.unplug_network(delta.compute_id,
                                                    nic.network_id)
             except Exception:
-                LOG.exception("Unable to unplug network %s",
-                              nic.network_id)
-
-            port_id = nic.port_id
-            try:
-                self.network_driver.delete_port(port_id)
-            except Exception:
-                LOG.exception("Unable to delete port %s", port_id)
+                pass
 
 
 class HandleNetworkDeltas(BaseNetworkTask):
@@ -409,28 +284,35 @@ class HandleNetworkDeltas(BaseNetworkTask):
     networks based on delta
     """
 
-    def execute(self, deltas, loadbalancer):
+    def execute(self, deltas):
         """Handle network plugging based off deltas."""
-        amphorae = {amp.id: amp for amp in loadbalancer.amphorae}
-
-        updated_ports = {}
-        handle_delta = HandleNetworkDelta()
-
+        added_ports = {}
         for amp_id, delta in deltas.items():
-            ret = handle_delta.execute(amphorae[amp_id], delta)
-            updated_ports.update(ret)
-
-        return updated_ports
+            added_ports[amp_id] = []
+            for nic in delta.add_nics:
+                interface = self.network_driver.plug_network(delta.compute_id,
+                                                             nic.network_id)
+                port = self.network_driver.get_port(interface.port_id)
+                port.network = self.network_driver.get_network(port.network_id)
+                for fixed_ip in port.fixed_ips:
+                    fixed_ip.subnet = self.network_driver.get_subnet(
+                        fixed_ip.subnet_id)
+                added_ports[amp_id].append(port)
+            for nic in delta.delete_nics:
+                try:
+                    self.network_driver.unplug_network(delta.compute_id,
+                                                       nic.network_id)
+                except base.NetworkNotFound:
+                    LOG.debug("Network %d not found ", nic.network_id)
+                except Exception:
+                    LOG.exception("Unable to unplug network")
+        return added_ports
 
     def revert(self, result, deltas, *args, **kwargs):
         """Handle a network plug or unplug failures."""
 
         if isinstance(result, failure.Failure):
             return
-
-        if not deltas:
-            return
-
         for amp_id, delta in deltas.items():
             LOG.warning("Unable to plug networks for amp id %s",
                         delta.amphora_id)
@@ -441,15 +323,8 @@ class HandleNetworkDeltas(BaseNetworkTask):
                 try:
                     self.network_driver.unplug_network(delta.compute_id,
                                                        nic.network_id)
-                except Exception:
-                    LOG.exception("Unable to unplug network %s",
-                                  nic.network_id)
-
-                port_id = nic.port_id
-                try:
-                    self.network_driver.delete_port(port_id)
-                except Exception:
-                    LOG.exception("Unable to delete port %s", port_id)
+                except base.NetworkNotFound:
+                    pass
 
 
 class PlugVIP(BaseNetworkTask):
@@ -498,13 +373,17 @@ class UpdateVIPSecurityGroup(BaseNetworkTask):
         Task is idempotent and safe to retry.
         """
 
-        LOG.debug("Setup SG for loadbalancer id: %s", loadbalancer_id)
+        LOG.debug("Setting up VIP SG for load balancer id: %s",
+                  loadbalancer_id)
 
         loadbalancer = self.lb_repo.get(db_apis.get_session(),
                                         id=loadbalancer_id)
 
-        return self.network_driver.update_vip_sg(loadbalancer,
-                                                 loadbalancer.vip)
+        sg_id = self.network_driver.update_vip_sg(loadbalancer,
+                                                  loadbalancer.vip)
+        LOG.info("Set up VIP SG %s for load balancer %s complete",
+                 sg_id if sg_id else "None", loadbalancer_id)
+        return sg_id
 
 
 class GetSubnetFromVIP(BaseNetworkTask):
@@ -515,7 +394,11 @@ class GetSubnetFromVIP(BaseNetworkTask):
 
         LOG.debug("Getting subnet for LB: %s", loadbalancer.id)
 
-        return self.network_driver.get_subnet(loadbalancer.vip.subnet_id)
+        subnet = self.network_driver.get_subnet(loadbalancer.vip.subnet_id)
+        LOG.info("Got subnet %s for load balancer %s",
+                 loadbalancer.vip.subnet_id if subnet else "None",
+                 loadbalancer.id)
+        return subnet
 
 
 class PlugVIPAmpphora(BaseNetworkTask):
@@ -571,12 +454,20 @@ class AllocateVIP(BaseNetworkTask):
     def execute(self, loadbalancer):
         """Allocate a vip to the loadbalancer."""
 
-        LOG.debug("Allocate_vip port_id %s, subnet_id %s,"
-                  "ip_address %s",
+        LOG.debug("Allocating vip port id %s, subnet id %s, ip address %s for "
+                  "load balancer %s",
                   loadbalancer.vip.port_id,
                   loadbalancer.vip.subnet_id,
-                  loadbalancer.vip.ip_address)
-        return self.network_driver.allocate_vip(loadbalancer)
+                  loadbalancer.vip.ip_address,
+                  loadbalancer.id)
+        vip = self.network_driver.allocate_vip(loadbalancer)
+        LOG.info("Allocated vip with port id %s, subnet id %s, ip address %s "
+                 "for load balancer %s",
+                 loadbalancer.vip.port_id,
+                 loadbalancer.vip.subnet_id,
+                 loadbalancer.vip.ip_address,
+                 loadbalancer.id)
+        return vip
 
     def revert(self, result, loadbalancer, *args, **kwargs):
         """Handle a failure to allocate vip."""
@@ -730,10 +621,6 @@ class ApplyQos(BaseNetworkTask):
         if not amps_data:
             amps_data = loadbalancer.amphorae
 
-        amps_data = [amp
-                     for amp in amps_data
-                     if amp.status == constants.AMPHORA_ALLOCATED]
-
         apply_qos = ApplyQosAmphora()
         for amp_data in amps_data:
             apply_qos._apply_qos_on_vrrp_port(loadbalancer, amp_data,
