@@ -403,17 +403,18 @@ class AmphoraFlows(object):
         amp_for_failover_flow.add(network_tasks.CalculateAmphoraDelta(
             name=prefix + '-' + constants.CALCULATE_AMPHORA_DELTA,
             requires=(constants.LOADBALANCER, constants.AMPHORA,
-                      constants.AVAILABILITY_ZONE),
+                      constants.AVAILABILITY_ZONE, constants.VRRP_PORT),
+            rebind={constants.VRRP_PORT: constants.BASE_PORT},
             provides=constants.DELTA))
 
         amp_for_failover_flow.add(network_tasks.HandleNetworkDelta(
             name=prefix + '-' + constants.HANDLE_NETWORK_DELTA,
             requires=(constants.AMPHORA, constants.DELTA),
-            provides=constants.UPDATED_PORTS))
+            provides=constants.ADDED_PORTS))
 
         amp_for_failover_flow.add(amphora_driver_tasks.AmphoraePostNetworkPlug(
             name=prefix + '-' + constants.AMPHORAE_POST_NETWORK_PLUG,
-            requires=(constants.LOADBALANCER, constants.UPDATED_PORTS)))
+            requires=(constants.LOADBALANCER, constants.ADDED_PORTS)))
 
         return amp_for_failover_flow
 
@@ -522,7 +523,7 @@ class AmphoraFlows(object):
             constants.CONN_MAX_RETRIES:
                 CONF.haproxy_amphora.active_connection_max_retries,
             constants.CONN_RETRY_INTERVAL:
-                CONF.haproxy_amphora.active_connection_rety_interval}
+                CONF.haproxy_amphora.active_connection_retry_interval}
 
         # Listeners update needs to be run on all amphora to update
         # their peer configurations. So parallelize this with an
