@@ -13,6 +13,7 @@
 # under the License.
 #
 
+import copy
 from cryptography import fernet
 from oslo_config import cfg
 from oslo_log import log as logging
@@ -334,8 +335,9 @@ class AmphoraPostVIPPlug(BaseAmphoraTask):
             **amphorae_network_config[
                 amphora.get(constants.ID)][constants.VRRP_PORT])
         # Required for noop-case
-        vip_arg = amphorae_network_config[amphora.get(
-            constants.ID)][constants.VIP_SUBNET]
+        vip_arg = copy.deepcopy(
+            amphorae_network_config[
+                amphora.get(constants.ID)][constants.VIP_SUBNET])
         if vip_arg:
             host_routes = vip_arg.get('host_routes')
             if host_routes:
@@ -357,8 +359,6 @@ class AmphoraPostVIPPlug(BaseAmphoraTask):
             return
         LOG.warning("Reverting post vip plug.")
         self.task_utils.mark_amphora_status_error(amphora.get(constants.ID))
-        self.task_utils.mark_loadbalancer_prov_status_error(
-            loadbalancer[constants.LOADBALANCER_ID])
 
 
 class AmphoraePostVIPPlug(BaseAmphoraTask):
@@ -374,14 +374,6 @@ class AmphoraePostVIPPlug(BaseAmphoraTask):
                                       loadbalancer,
                                       amphorae_network_config)
 
-    def revert(self, result, loadbalancer, *args, **kwargs):
-        """Handle a failed amphora vip plug notification."""
-        if isinstance(result, failure.Failure):
-            return
-        LOG.warning("Reverting amphorae post vip plug.")
-        self.task_utils.mark_loadbalancer_prov_status_error(
-            loadbalancer[constants.LOADBALANCER_ID])
-
 
 class AmphoraCertUpload(BaseAmphoraTask):
     """Upload a certificate to the amphora."""
