@@ -107,10 +107,10 @@ class ComputeCreate(BaseComputeTask):
             config_drive_files['/etc/rsyslog.d/10-rsyslog.conf'] = (
                 logging_cfg.build_logging_config())
 
+            udtemplater = user_data_jinja_cfg.UserDataJinjaCfg()
+            user_data = udtemplater.build_user_data_config(
+                config_drive_files if user_data_config_drive else {})
             if user_data_config_drive:
-                udtemplater = user_data_jinja_cfg.UserDataJinjaCfg()
-                user_data = udtemplater.build_user_data_config(
-                    config_drive_files)
                 config_drive_files = None
 
             compute_id = self.compute.build(
@@ -127,8 +127,8 @@ class ComputeCreate(BaseComputeTask):
                 server_group_id=server_group_id,
                 availability_zone=amp_availability_zone)
 
-            LOG.debug("Server created with id: %s for amphora id: %s",
-                      compute_id, amphora_id)
+            LOG.info("Server created with id: %s for amphora id: %s",
+                     compute_id, amphora_id)
             return compute_id
 
         except Exception:
@@ -165,7 +165,8 @@ class CertComputeCreate(ComputeCreate):
         """
 
         # load client certificate
-        with open(CONF.controller_worker.client_ca, 'r') as client_ca:
+        with open(CONF.controller_worker.client_ca,
+                  'r', encoding='utf-8') as client_ca:
             ca = client_ca.read()
 
         key = utils.get_compatible_server_certs_key_passphrase()
@@ -311,7 +312,7 @@ class NovaServerGroupCreate(BaseComputeTask):
             LOG.error("Failed to delete server group.  Resources may "
                       "still be in use for server group: %(sg)s due to "
                       "error: %(except)s",
-                      {'sg': server_group_id, 'except': e})
+                      {'sg': server_group_id, 'except': str(e)})
 
 
 class NovaServerGroupDelete(BaseComputeTask):
