@@ -19,6 +19,7 @@ from oslo_utils import uuidutils
 
 from octavia.common import constants
 import octavia.common.context
+from octavia.common import data_models
 from octavia.common import exceptions
 from octavia.db import repositories
 from octavia.tests.functional.api.v2 import base
@@ -31,7 +32,7 @@ class TestL7Rule(base.BaseAPITest):
     root_tag_links = 'rules_links'
 
     def setUp(self):
-        super(TestL7Rule, self).setUp()
+        super().setUp()
         self.lb = self.create_load_balancer(uuidutils.generate_uuid())
         self.lb_id = self.lb.get('loadbalancer').get('id')
         self.project_id = self.lb.get('loadbalancer').get('project_id')
@@ -327,7 +328,7 @@ class TestL7Rule(base.BaseAPITest):
         links = middle[self.root_tag_links]
         self.assertEqual(1, len(objs))
         self.assertEqual(2, len(links))
-        self.assertItemsEqual(['previous', 'next'],
+        self.assertCountEqual(['previous', 'next'],
                               [link['rel'] for link in links])
 
     def test_get_all_fields_filter(self):
@@ -865,6 +866,15 @@ class TestL7Rule(base.BaseAPITest):
     def test_create_bad_cases_with_ssl_rule_types(self):
         self._test_bad_cases_with_ssl_rule_types()
 
+    def test_create_over_quota(self):
+        self.start_quota_mock(data_models.L7Rule)
+        l7rule = {'compare_type': 'REGEX',
+                  'invert': False,
+                  'type': 'PATH',
+                  'value': '/images*',
+                  'admin_state_up': True}
+        self.post(self.l7rules_path, self._build_body(l7rule), status=403)
+
     def test_update(self):
         api_l7rule = self.create_l7rule(
             self.l7policy_id, constants.L7RULE_TYPE_PATH,
