@@ -271,7 +271,7 @@ class PoolModelTest(base.OctaviaDBTestBase, ModelTestMixin):
 class MemberModelTest(base.OctaviaDBTestBase, ModelTestMixin):
 
     def setUp(self):
-        super(MemberModelTest, self).setUp()
+        super().setUp()
         self.pool = self.create_pool(self.session)
 
     def test_create(self):
@@ -317,7 +317,7 @@ class MemberModelTest(base.OctaviaDBTestBase, ModelTestMixin):
 class SessionPersistenceModelTest(base.OctaviaDBTestBase, ModelTestMixin):
 
     def setUp(self):
-        super(SessionPersistenceModelTest, self).setUp()
+        super().setUp()
         self.pool = self.create_pool(self.session)
 
     def test_create(self):
@@ -449,7 +449,7 @@ class ListenerModelTest(base.OctaviaDBTestBase, ModelTestMixin):
 class ListenerStatisticsModelTest(base.OctaviaDBTestBase, ModelTestMixin):
 
     def setUp(self):
-        super(ListenerStatisticsModelTest, self).setUp()
+        super().setUp()
         self.listener = self.create_listener(self.session)
         self.amphora = self.create_amphora(self.session)
 
@@ -486,7 +486,7 @@ class ListenerStatisticsModelTest(base.OctaviaDBTestBase, ModelTestMixin):
 class HealthMonitorModelTest(base.OctaviaDBTestBase, ModelTestMixin):
 
     def setUp(self):
-        super(HealthMonitorModelTest, self).setUp()
+        super().setUp()
         self.pool = self.create_pool(self.session)
 
     def test_create(self):
@@ -494,7 +494,8 @@ class HealthMonitorModelTest(base.OctaviaDBTestBase, ModelTestMixin):
 
     def test_update(self):
         health_monitor = self.create_health_monitor(self.session, self.pool.id)
-        health_monitor.name = 'test1'
+        with self.session.begin():
+            health_monitor.name = 'test1'
         new_health_monitor = self.session.query(
             models.HealthMonitor).filter_by(
                 pool_id=health_monitor.pool_id).first()
@@ -577,7 +578,7 @@ class LoadBalancerModelTest(base.OctaviaDBTestBase, ModelTestMixin):
 class VipModelTest(base.OctaviaDBTestBase, ModelTestMixin):
 
     def setUp(self):
-        super(VipModelTest, self).setUp()
+        super().setUp()
         self.load_balancer = self.create_load_balancer(self.session)
 
     def test_create(self):
@@ -585,7 +586,8 @@ class VipModelTest(base.OctaviaDBTestBase, ModelTestMixin):
 
     def test_update(self):
         vip = self.create_vip(self.session, self.load_balancer.id)
-        vip.ip_address = "10.0.0.1"
+        with self.session.begin():
+            vip.ip_address = "10.0.0.1"
         new_vip = self.session.query(models.Vip).filter_by(
             load_balancer_id=self.load_balancer.id).first()
         self.assertEqual("10.0.0.1", new_vip.ip_address)
@@ -610,7 +612,7 @@ class VipModelTest(base.OctaviaDBTestBase, ModelTestMixin):
 class SNIModelTest(base.OctaviaDBTestBase, ModelTestMixin):
 
     def setUp(self):
-        super(SNIModelTest, self).setUp()
+        super().setUp()
         self.listener = self.create_listener(self.session)
 
     def test_create(self):
@@ -643,7 +645,7 @@ class SNIModelTest(base.OctaviaDBTestBase, ModelTestMixin):
 class AmphoraModelTest(base.OctaviaDBTestBase, ModelTestMixin):
 
     def setUp(self):
-        super(AmphoraModelTest, self).setUp()
+        super().setUp()
         self.load_balancer = self.create_load_balancer(self.session)
 
     def test_create(self):
@@ -678,7 +680,7 @@ class AmphoraModelTest(base.OctaviaDBTestBase, ModelTestMixin):
 
 class AmphoraHealthModelTest(base.OctaviaDBTestBase, ModelTestMixin):
     def setUp(self):
-        super(AmphoraHealthModelTest, self).setUp()
+        super().setUp()
         self.amphora = self.create_amphora(self.session)
 
     def test_create(self):
@@ -708,7 +710,7 @@ class AmphoraHealthModelTest(base.OctaviaDBTestBase, ModelTestMixin):
 
 class L7PolicyModelTest(base.OctaviaDBTestBase, ModelTestMixin):
     def setUp(self):
-        super(L7PolicyModelTest, self).setUp()
+        super().setUp()
         self.listener = self.create_listener(self.session)
 
     def test_create(self):
@@ -718,8 +720,9 @@ class L7PolicyModelTest(base.OctaviaDBTestBase, ModelTestMixin):
     def test_update(self):
         l7policy = self.create_l7policy(self.session, self.listener.id)
         pool = self.create_pool(self.session)
-        l7policy.action = constants.L7POLICY_ACTION_REDIRECT_TO_POOL
-        l7policy.redirect_pool_id = pool.id
+        with self.session.begin():
+            l7policy.action = constants.L7POLICY_ACTION_REDIRECT_TO_POOL
+            l7policy.redirect_pool_id = pool.id
         new_l7policy = self.session.query(
             models.L7Policy).filter_by(id=l7policy.id).first()
         self.assertEqual(pool.id, new_l7policy.redirect_pool_id)
@@ -758,8 +761,9 @@ class L7PolicyModelTest(base.OctaviaDBTestBase, ModelTestMixin):
     def test_pool_relationship(self):
         l7policy = self.create_l7policy(self.session, self.listener.id)
         self.create_pool(self.session, id=self.FAKE_UUID_2)
-        l7policy.action = constants.L7POLICY_ACTION_REDIRECT_TO_POOL
-        l7policy.redirect_pool_id = self.FAKE_UUID_2
+        with self.session.begin():
+            l7policy.action = constants.L7POLICY_ACTION_REDIRECT_TO_POOL
+            l7policy.redirect_pool_id = self.FAKE_UUID_2
         new_l7policy = self.session.query(
             models.L7Policy).filter_by(id=l7policy.id).first()
         self.assertIsNotNone(new_l7policy.redirect_pool)
@@ -826,7 +830,7 @@ class L7PolicyModelTest(base.OctaviaDBTestBase, ModelTestMixin):
 class L7RuleModelTest(base.OctaviaDBTestBase, ModelTestMixin):
 
     def setUp(self):
-        super(L7RuleModelTest, self).setUp()
+        super().setUp()
         self.listener = self.create_listener(self.session)
         self.l7policy = self.create_l7policy(self.session, self.listener.id)
 
@@ -872,7 +876,7 @@ class L7RuleModelTest(base.OctaviaDBTestBase, ModelTestMixin):
 class TestDataModelConversionTest(base.OctaviaDBTestBase, ModelTestMixin):
 
     def setUp(self):
-        super(TestDataModelConversionTest, self).setUp()
+        super().setUp()
         self.lb = self.create_load_balancer(self.session)
         self.amphora = self.create_amphora(self.session)
         self.associate_amphora(self.lb, self.amphora)
@@ -1329,7 +1333,7 @@ class TestDataModelConversionTest(base.OctaviaDBTestBase, ModelTestMixin):
 class TestDataModelManipulations(base.OctaviaDBTestBase, ModelTestMixin):
 
     def setUp(self):
-        super(TestDataModelManipulations, self).setUp()
+        super().setUp()
         self.lb = self.create_load_balancer(self.session)
         self.amphora = self.create_amphora(self.session)
         self.associate_amphora(self.lb, self.amphora)
@@ -1748,7 +1752,7 @@ class TestDataModelManipulations(base.OctaviaDBTestBase, ModelTestMixin):
 class FlavorModelTest(base.OctaviaDBTestBase, ModelTestMixin):
 
     def setUp(self):
-        super(FlavorModelTest, self).setUp()
+        super().setUp()
         self.profile = self.create_flavor_profile(self.session)
 
     def test_create(self):
