@@ -21,7 +21,7 @@ from octavia.tests.unit.common.sample_configs import sample_configs_combined
 
 class HAProxyCompatTestCase(base.TestCase):
     def setUp(self):
-        super(HAProxyCompatTestCase, self).setUp()
+        super().setUp()
         self.old_haproxy_global = (
             "# Configuration for loadbalancer sample_loadbalancer_id_1\n"
             "global\n"
@@ -31,6 +31,8 @@ class HAProxyCompatTestCase(base.TestCase):
             "    log /run/rsyslog/octavia/log local1 notice\n"
             "    stats socket /var/lib/octavia/sample_loadbalancer_id_1.sock"
             " mode 0666 level user\n"
+            "    server-state-file /var/lib/octavia/sample_loadbalancer_id_1"
+            "/servers-state\n"
             "    maxconn {maxconn}\n\n"
             "defaults\n"
             "    log global\n"
@@ -38,7 +40,7 @@ class HAProxyCompatTestCase(base.TestCase):
             "    option redispatch\n"
             "    option splice-request\n"
             "    option splice-response\n"
-            "    option http-keep-alive\n\n\n\n"
+            "    option http-keep-alive\n\n\n\n\n"
             "frontend sample_listener_id_1\n"
             "    maxconn {maxconn}\n"
             "    bind 10.0.0.2:80\n"
