@@ -11,14 +11,12 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-
 import socket
-
-import mock
-import six
+from unittest import mock
 
 from octavia.amphorae.backends.utils import haproxy_query as query
 from octavia.common import constants
+from octavia.common import utils as octavia_utils
 import octavia.tests.unit.base as base
 
 STATS_SOCKET_SAMPLE = (
@@ -41,7 +39,7 @@ STATS_SOCKET_SAMPLE = (
     "tcp-servers:listener-id,id-34833,0,0,0,0,,0,0,0,,0,,0,0,0,0,UP,1,1,0,1,1,"
     "560,560,,1,5,1,,0,,2,0,,0,L4TOUT,,30000,,,,,,,0,,,,0,0,,,,,-1,,,0,0,0,0,"
     "\n"
-    "tcp-servers:listener-id,id-34836,0,0,0,0,,0,0,0,,0,,0,0,0,0,UP,1,1,0,1,1,"
+    "tcp-servers:listener-id,id-34836,0,0,0,0,,0,0,0,,0,,0,0,0,0,UP,0,1,0,1,1,"
     "552,552,,1,5,2,,0,,2,0,,0,L4TOUT,,30001,,,,,,,0,,,,0,0,,,,,-1,,,0,0,0,0,"
     "\n"
     "tcp-servers:listener-id,id-34839,0,0,0,0,,0,0,0,,0,,0,0,0,0,DRAIN,0,1,0,"
@@ -50,7 +48,7 @@ STATS_SOCKET_SAMPLE = (
     "tcp-servers:listener-id,id-34842,0,0,0,0,,0,0,0,,0,,0,0,0,0,MAINT,0,1,0,"
     "0,0,552,0,,1,5,2,,0,,2,0,,0,L7OK,,30001,,,,,,,0,,,,0,0,,,,,-1,,,0,0,0,0,"
     "\n"
-    "tcp-servers:listener-id,BACKEND,0,0,0,0,200,0,0,0,0,0,,0,0,0,0,UP,0,0,0,,"
+    "tcp-servers:listener-id,BACKEND,0,0,0,0,200,0,0,0,0,0,,0,0,0,0,UP,1,0,0,,"
     "1,552,552,,1,5,0,,0,,1,0,,0,,,,,,,,,,,,,,0,0,0,0,0,0,-1,,,0,0,0,0,"
 )
 
@@ -75,7 +73,7 @@ INFO_SOCKET_SAMPLE = (
 class QueryTestCase(base.TestCase):
     def setUp(self):
         self.q = query.HAProxyQuery('')
-        super(QueryTestCase, self).setUp()
+        super().setUp()
 
     @mock.patch('socket.socket')
     def test_query(self, mock_socket):
@@ -88,7 +86,7 @@ class QueryTestCase(base.TestCase):
         self.q._query('test')
 
         sock.connect.assert_called_once_with('')
-        sock.send.assert_called_once_with(six.b('test\n'))
+        sock.send.assert_called_once_with(octavia_utils.b('test\n'))
         sock.recv.assert_called_with(1024)
         self.assertTrue(sock.close.called)
 
@@ -107,7 +105,7 @@ class QueryTestCase(base.TestCase):
                 'pool_uuid': 'tcp-servers',
                 'members':
                     {'id-34833': constants.UP,
-                     'id-34836': constants.UP,
+                     'id-34836': constants.DRAIN,
                      'id-34839': constants.DRAIN,
                      'id-34842': constants.MAINT}},
              'http-servers:listener-id': {
