@@ -11,10 +11,8 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-
 import errno
-
-import mock
+from unittest import mock
 
 from oslo_config import cfg
 from oslo_serialization import jsonutils
@@ -28,7 +26,7 @@ CONF = cfg.CONF
 class TestDriverListener(base.TestCase):
 
     def setUp(self):
-        super(TestDriverListener, self).setUp()
+        super().setUp()
 
     @mock.patch('octavia.api.drivers.driver_agent.driver_listener.memoryview')
     def test_recv(self, mock_memoryview):
