@@ -42,7 +42,7 @@ class TestLvsCfg(base.TestCase):
                "# Configuration for Listener sample_listener_id_1\n\n"
                "net_namespace amphora-haproxy\n\n"
                "virtual_server 10.0.0.2 80 {\n"
-               "    lb_algo rr\n"
+               "    lb_algo wrr\n"
                "    lb_kind NAT\n"
                "    protocol UDP\n"
                "    persistence_timeout 33\n"
@@ -88,7 +88,7 @@ class TestLvsCfg(base.TestCase):
                "# Configuration for Listener sample_listener_id_1\n\n"
                "net_namespace amphora-haproxy\n\n"
                "virtual_server 10.0.0.2 80 {\n"
-               "    lb_algo rr\n"
+               "    lb_algo wrr\n"
                "    lb_kind NAT\n"
                "    protocol UDP\n"
                "    delay_loop 30\n"
@@ -131,7 +131,7 @@ class TestLvsCfg(base.TestCase):
                "# Configuration for Listener sample_listener_id_1\n\n"
                "net_namespace amphora-haproxy\n\n"
                "virtual_server 10.0.0.2 80 {\n"
-               "    lb_algo rr\n"
+               "    lb_algo wrr\n"
                "    lb_kind NAT\n"
                "    protocol UDP\n"
                "    delay_loop 30\n"
@@ -174,7 +174,7 @@ class TestLvsCfg(base.TestCase):
                "# Configuration for Listener sample_listener_id_1\n\n"
                "net_namespace amphora-haproxy\n\n"
                "virtual_server 10.0.0.2 80 {\n"
-               "    lb_algo rr\n"
+               "    lb_algo wrr\n"
                "    lb_kind NAT\n"
                "    protocol UDP\n"
                "    delay_loop 30\n"
@@ -229,7 +229,7 @@ class TestLvsCfg(base.TestCase):
                "# Configuration for Listener sample_listener_id_1\n\n"
                "net_namespace amphora-haproxy\n\n"
                "virtual_server 10.0.0.2 80 {\n"
-               "    lb_algo rr\n"
+               "    lb_algo wrr\n"
                "    lb_kind NAT\n"
                "    protocol UDP\n\n\n"
                "    # Configuration for Pool sample_pool_id_0\n"
@@ -247,7 +247,7 @@ class TestLvsCfg(base.TestCase):
                "# Configuration for Listener sample_listener_id_1\n\n"
                "net_namespace amphora-haproxy\n\n"
                "virtual_server 10.0.0.2 80 {\n"
-               "    lb_algo rr\n"
+               "    lb_algo wrr\n"
                "    lb_kind NAT\n"
                "    protocol UDP\n\n\n"
                "    # Pool sample_pool_id_1 is disabled\n"
@@ -358,7 +358,7 @@ class TestLvsCfg(base.TestCase):
                "# Configuration for Listener sample_listener_id_1\n\n"
                "net_namespace amphora-haproxy\n\n"
                "virtual_server 10.0.0.2 80 {\n"
-               "    lb_algo rr\n"
+               "    lb_algo wrr\n"
                "    lb_kind NAT\n"
                "    protocol UDP\n"
                "    delay_loop 30\n"
@@ -419,7 +419,7 @@ class TestLvsCfg(base.TestCase):
                "# Configuration for Listener sample_listener_id_1\n\n"
                "net_namespace amphora-haproxy\n\n"
                "virtual_server 10.0.0.2 80 {\n"
-               "    lb_algo rr\n"
+               "    lb_algo wrr\n"
                "    lb_kind NAT\n"
                "    protocol UDP\n"
                "    delay_loop 30\n"
@@ -477,7 +477,7 @@ class TestLvsCfg(base.TestCase):
                "# Configuration for Listener sample_listener_id_1\n\n"
                "net_namespace amphora-haproxy\n\n"
                "virtual_server 10.0.0.2 80 {\n"
-               "    lb_algo rr\n"
+               "    lb_algo wrr\n"
                "    lb_kind NAT\n"
                "    protocol SCTP\n"
                "    persistence_timeout 33\n"
@@ -523,7 +523,7 @@ class TestLvsCfg(base.TestCase):
                "# Configuration for Listener sample_listener_id_1\n\n"
                "net_namespace amphora-haproxy\n\n"
                "virtual_server 10.0.0.2 80 {\n"
-               "    lb_algo rr\n"
+               "    lb_algo wrr\n"
                "    lb_kind NAT\n"
                "    protocol SCTP\n"
                "    delay_loop 30\n"
@@ -566,7 +566,7 @@ class TestLvsCfg(base.TestCase):
                "# Configuration for Listener sample_listener_id_1\n\n"
                "net_namespace amphora-haproxy\n\n"
                "virtual_server 10.0.0.2 80 {\n"
-               "    lb_algo rr\n"
+               "    lb_algo wrr\n"
                "    lb_kind NAT\n"
                "    protocol SCTP\n"
                "    delay_loop 30\n"
@@ -609,7 +609,7 @@ class TestLvsCfg(base.TestCase):
                "# Configuration for Listener sample_listener_id_1\n\n"
                "net_namespace amphora-haproxy\n\n"
                "virtual_server 10.0.0.2 80 {\n"
-               "    lb_algo rr\n"
+               "    lb_algo wrr\n"
                "    lb_kind NAT\n"
                "    protocol SCTP\n"
                "    delay_loop 30\n"
@@ -749,7 +749,7 @@ class TestLvsCfg(base.TestCase):
                "# Configuration for Listener sample_listener_id_1\n\n"
                "net_namespace amphora-haproxy\n\n"
                "virtual_server 10.0.0.2 80 {\n"
-               "    lb_algo rr\n"
+               "    lb_algo wrr\n"
                "    lb_kind NAT\n"
                "    protocol SCTP\n"
                "    delay_loop 30\n"
@@ -810,7 +810,7 @@ class TestLvsCfg(base.TestCase):
                "# Configuration for Listener sample_listener_id_1\n\n"
                "net_namespace amphora-haproxy\n\n"
                "virtual_server 10.0.0.2 80 {\n"
-               "    lb_algo rr\n"
+               "    lb_algo wrr\n"
                "    lb_kind NAT\n"
                "    protocol SCTP\n"
                "    delay_loop 30\n"
